@@ -1,8 +1,10 @@
-require 5;
 package Pod::Simple::Debug;
+
+require 5.006;
 use strict;
-use vars qw($VERSION );
-$VERSION = '3.30_1';
+use warnings;
+
+our $VERSION = '3.33_02';
 
 sub import {
   my($value,$variable);
@@ -47,10 +49,10 @@ sub import {
     # make a not-really-constant
     *Pod::Simple::DEBUG = sub () { $$variable } ;
     $$variable = $value;
-    print "# Starting Pod::Simple::DEBUG = non-constant $variable with val $value\n";
+    print STDERR "# Starting Pod::Simple::DEBUG = non-constant $variable with val $value\n";
   } else {
     *Pod::Simple::DEBUG = eval " sub () { $value } ";
-    print "# Starting Pod::Simple::DEBUG = $value\n";
+    print STDERR "# Starting Pod::Simple::DEBUG = $value\n";
   }
   
   require Pod::Simple;
