@@ -1,15 +1,16 @@
-
-require 5;
 package Pod::Simple::DumpAsXML;
-$VERSION = '3.30_1';
-use Pod::Simple ();
-BEGIN {@ISA = ('Pod::Simple')}
 
+require 5.006;
 use strict;
-
+use warnings;
+use Pod::Simple ();
 use Carp ();
 use Text::Wrap qw(wrap);
 
+our $VERSION = '3.33_02';
+our @ISA     = ('Pod::Simple');
+
+
 BEGIN { *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG }
 
 sub new {
@@ -27,7 +28,7 @@ sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
   my $fh = $_[0]{'output_fh'};
   my($key, $value);
-  DEBUG and print "++ $_[1]\n";
+  DEBUG and print STDERR "++ $_[1]\n";
   
   print $fh   '  ' x ($_[0]{'indent'} || 0),  "<", $_[1];
 
@@ -46,7 +47,7 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  DEBUG and print "== \"$_[1]\"\n";
+  DEBUG and print STDERR "== \"$_[1]\"\n";
   if(length $_[1]) {
     my $indent = '  ' x $_[0]{'indent'};
     my $text = $_[1];
@@ -59,7 +60,7 @@ sub _handle_text {
 }
 
 sub _handle_element_end {
-  DEBUG and print "-- $_[1]\n";
+  DEBUG and print STDERR "-- $_[1]\n";
   print {$_[0]{'output_fh'}}
    '  ' x --$_[0]{'indent'}, "</", $_[1], ">\n";
   return;
