@@ -1,14 +1,12 @@
-
-require 5;
 package Pod::Simple::LinkSection;
-  # Based somewhat dimly on Array::Autojoin
-use vars qw($VERSION );
-$VERSION = '3.30_1';
 
+require 5.006;
 use strict;
+use warnings;
 use Pod::Simple::BlackBox;
-use vars qw($VERSION );
-$VERSION = '3.30_1';
+  # Based somewhat dimly on Array::Autojoin
+
+our $VERSION = '3.33_02';
 
 use overload( # So it'll stringify nice
   '""'   => \&Pod::Simple::BlackBox::stringify_lol,
@@ -18,6 +16,8 @@ use overload( # So it'll stringify nice
   'fallback' => 1,         # turn on cleverness
 );
 
+no warnings 'redefine';
+
 sub tack_on {
   $_[0] = ['', {}, "$_[0]" ];
   return $_[0][2] .= $_[1];
