@@ -1,11 +1,12 @@
-
-require 5;
 package Pod::Simple::PullParserEndToken;
-use Pod::Simple::PullParserToken ();
+
+require 5.006;
 use strict;
-use vars qw(@ISA $VERSION);
-@ISA = ('Pod::Simple::PullParserToken');
-$VERSION = '3.30_1';
+use warnings;
+use Pod::Simple::PullParserToken ();
+
+our @ISA     = ('Pod::Simple::PullParserToken');
+our $VERSION = '3.33_02';
 
 sub new {  # Class->new(tagname);
   my $class = shift;
