@@ -1,10 +1,12 @@
-
-require 5;
 package Pod::Simple::PullParserToken;
- # Base class for tokens gotten from Pod::Simple::PullParser's $parser->get_token
-@ISA = ();
-$VERSION = '3.30_1';
+
+require 5.006;
 use strict;
+use warnings;
+# Base class for tokens gotten from Pod::Simple::PullParser's $parser->get_token
+
+our @ISA     = ();
+our $VERSION = '3.33_02';
 
 sub new {  # Class->new('type', stuff...);  ## Overridden in derived classes anyway
   my $class = shift;
@@ -50,7 +52,7 @@ Given a $parser that's an object of class Pod::Simple::PullParser
 (or a subclass)...
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print "Token: ", $token->dump, "\n";
+    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
     if($token->is_start) {
       ...access $token->tagname, $token->attr, etc...
 
@@ -104,7 +106,7 @@ This returns a handy stringified value of this object.  This
 is useful for debugging, as in:
 
   while(my $token = $parser->get_token) {
-    $DEBUG and print "Token: ", $token->dump, "\n";
+    $DEBUG and print STDERR "Token: ", $token->dump, "\n";
     ...
   }
 
