@@ -1,13 +1,13 @@
-
-
-require 5;
 package Pod::Simple::TextContent;
+
+require 5.006;
 use strict;
+use warnings;
 use Carp ();
 use Pod::Simple ();
-use vars qw( @ISA $VERSION );
-$VERSION = '3.30_1';
-@ISA = ('Pod::Simple');
+
+our $VERSION = '3.33_02';
+our @ISA     = ('Pod::Simple');
 
 sub new {
   my $self = shift;
@@ -25,6 +25,7 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
+  no warnings 'once';
   $_[1] =~ s/$Pod::Simple::shy//g;
   $_[1] =~ s/$Pod::Simple::nbsp/ /g;
   print {$_[0]{'output_fh'}} $_[1];
