@@ -1,9 +1,11 @@
-
-require 5;
 package Pod::Simple::Transcode;
+
+require 5.006;
 use strict;
-use vars qw($VERSION @ISA);
-$VERSION = '3.30_1';
+use warnings;
+
+our $VERSION = '3.33_02';
+our @ISA;
 
 BEGIN {
   if(defined &DEBUG) {;} # Okay
@@ -17,12 +19,12 @@ foreach my $class (
   '',
 ) {
   $class or die "Couldn't load any encoding classes";
-  DEBUG and print "About to try loading $class...\n";
+  DEBUG and print STDERR "About to try loading $class...\n";
   eval "require $class;";
   if($@) {
-    DEBUG and print "Couldn't load $class: $@\n";
+    DEBUG and print STDERR "Couldn't load $class: $@\n";
   } else {
-    DEBUG and print "OK, loaded $class.\n";
+    DEBUG and print STDERR "OK, loaded $class.\n";
     @ISA = ($class);
     last;
   }
