@@ -1,20 +1,22 @@
-
-require 5;
 package Pod::Simple::XMLOutStream;
+
+require 5.006;
 use strict;
+use warnings;
 use Carp ();
 use Pod::Simple ();
-use vars qw( $ATTR_PAD @ISA $VERSION $SORT_ATTRS);
-$VERSION = '3.30_1';
+
+our $VERSION = '3.33_02';
+our @ISA     = ('Pod::Simple');
+
 BEGIN {
-  @ISA = ('Pod::Simple');
   *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG;
 }
 
-$ATTR_PAD = "\n" unless defined $ATTR_PAD;
+our $ATTR_PAD = "\n" unless defined $ATTR_PAD;
  # Don't mess with this unless you know what you're doing.
 
-$SORT_ATTRS = 0 unless defined $SORT_ATTRS;
+our $SORT_ATTRS = 0 unless defined $SORT_ATTRS;
 
 sub new {
   my $self = shift;
@@ -31,7 +33,7 @@ sub _handle_element_start {
   # ($self, $element_name, $attr_hash_r)
   my $fh = $_[0]{'output_fh'};
   my($key, $value);
-  DEBUG and print "++ $_[1]\n";
+  DEBUG and print STDERR "++ $_[1]\n";
   print $fh "<", $_[1];
   if($SORT_ATTRS) {
     foreach my $key (sort keys %{$_[2]}) {
@@ -55,7 +57,7 @@ sub _handle_element_start {
 }
 
 sub _handle_text {
-  DEBUG and print "== \"$_[1]\"\n";
+  DEBUG and print STDERR "== \"$_[1]\"\n";
   if(length $_[1]) {
     my $text = $_[1];
     _xml_escape($text);
@@ -65,7 +67,7 @@ sub _handle_text {
 }
 
 sub _handle_element_end {
-  DEBUG and print "-- $_[1]\n";
+  DEBUG and print STDERR "-- $_[1]\n";
   print {$_[0]{'output_fh'}} "</", $_[1], ">";
   return;
 }
